@@ -1,5 +1,7 @@
 package constants
 
+import "k8s.io/apimachinery/pkg/types"
+
 // CredentialsMode enumerates the possible modes of operation for CCO
 type CredentialsMode string
 
@@ -91,6 +93,12 @@ const (
 	// CloudCredOperatorConfig is the name of the credentialsrequest.operator.openshift.io CR holding CCO's config
 	CloudCredOperatorConfig = "cluster"
 
+	// CloudCredOperatorConfigTimestampAnnotation is the annotation controllers can update to trigger a status sync.
+	CloudCredOperatorConfigTimestampAnnotation = "cloudcredential.operator.openshift.io/statussync"
+
+	// CloudCredClusterOperatorName is the name of the CCO's ClusterOperator object
+	CloudCredClusterOperatorName = "cloud-credential"
+
 	// CloudCredSecretNamespace is where the cloud credentials can be found
 	CloudCredSecretNamespace = "kube-system"
 
@@ -106,6 +114,10 @@ const (
 	// VSphereCloudCredSecretName is the name of the secret where credentials
 	// for vSphere are stored.
 	VSphereCloudCredSecretName = "vsphere-creds"
+
+	// KubevirtCloudCredSecretName is the name of the secret where credentials
+	// for Kubevirt are stored.
+	KubevirtCloudCredSecretName = "kubevirt-credentials"
 )
 
 var (
@@ -118,4 +130,38 @@ var (
 		ModeDegraded,
 		ModeUnknown,
 	}
+
+	// Add known new credentials for next version upgrade
+
+	// AWSUpcomingSecrets contains the list of known new AWS credential secrets for the next version of OpenShift
+	AWSUpcomingSecrets = []types.NamespacedName{}
+	// AzureUpcomingSecrets contains the list of known new Azure credential secrets for the next version of OpenShift
+	AzureUpcomingSecrets = []types.NamespacedName{}
+	// GCPUpcomingSecrets contains the list of known new GCP credential secrets for the next version of OpenShift
+	GCPUpcomingSecrets = []types.NamespacedName{
+		{
+			Namespace: "openshift-cluster-csi-drivers",
+			Name:      "gcp-pd-cloud-credentials",
+		},
+		{
+			Namespace: "openshift-cloud-credential-operator",
+			Name:      "cloud-credential-operator-gcp-ro-creds",
+		},
+	}
+	// OpenStackUpcomingSecrets contains the list of known new OpenStack credential secrets for the next version of OpenShift
+	OpenStackUpcomingSecrets = []types.NamespacedName{
+		{
+			Namespace: "openshift-cluster-csi-drivers",
+			Name:      "openstack-cloud-credentials",
+		},
+	}
+	// OvirtUpcomingSecrets contains the list of known new oVirt credential secrets for the next version of OpenShift
+	OvirtUpcomingSecrets = []types.NamespacedName{}
+	// VsphereUpcomingSecrets contains the list of known new vSphere credential secrets for the next version of OpenShift
+	VsphereUpcomingSecrets = []types.NamespacedName{
+		{
+			Namespace: "openshift-cluster-storage-operator",
+			Name:      "openshift-vsphere-problem-detector",
+		},
+	}
 )
